==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libconnection/connection.h <==
// Handle a connection to a LysKOM server.
//
// $Id: connection.h,v 1.22 1994/07/30 05:47:53 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef CONNECTION__
#define CONNECTION__

/* Needed by isc.h */
#include <stddef.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <time.h>
#include <stdarg.h>
/* End isc.h */

#include <SLList.h>
#include "server-info.h"

extern "C" {
#include "isc.h"
};

#include "prot-a-LyStr.h"
#include "misc.h"

// The class Connection handles communication with any number of
// LysKOM servers. It uses the ISC system. You can also have other
// IscSessions, and use static IscEvent*Connection::get_event(int
// timeout) to get events from them (nilkom uses this to read from the
// keyboard).
//
class Connection {
  public:
    // All Connections must share the same IscMaster. If you only have a
    // single Connection you can leave out the IscMaster argument, and an
    // IscMaster will be made for you. There is, however, no way for you
    // to get hold on that IscMaster.
    Connection(char *hostname, char *portnum, IscMaster *master=NULL);
    ~Connection();

    // Send a question. Don't flush it. All routines that await input
    // automatically flushes. Call drain() or get_event() to force the
    // questions to be flushed.
    void send_question(const prot_a_LyStr &str);

    // Parse any input that is available. Returns st_pending if no
    // input was available during TIMEOUT milliseconds. Returns
    // st_ok as soon as anything has been received. Note: there is
    // currently no way to wait for input on a specific Connection.
    // This will return as soon as there has been any event on any of
    // the IscSessions in the IscMaster. Returns st_error if something
    // is wrong with the connection - if that happens, you should
    // probably kill the connection and start a new one.
    static Status drain(int timeout=0);

    // Parse any input that is available. Return any IscEvent that has
    // been received from an IscSession that is not a Connection.
    // Return NULL if an event was received from a Connection (that
    // event has already been handled). Return an ISC_EVENT_TIMEOUT if
    // the timeout limit is reached. The event that is returned should
    // be disposed of with isc_dispose(). You are in trouble if this
    // returns an ISC_EVENT_ERROR. This might return the special value
    // &Connection::error_event if the connection was lost or something
    // similarily serious happens.
    static IscEvent *get_event(int timeout=0);
    static IscEvent error_event;

    // Register a function that will be called whenever an async
    // message has arrived. The first argument to register_async will
    // be passed as the first argument to the handler.
    void register_async(void *, void (*new_sinc)(void *, prot_a_LyStr));

    Server_info  * get_server_info();

  private:
    // The master control block. This is shared between all Connections.
    static IscMaster    *mcb;

    // FIXME+++: Support for multiple connections must be added.
    static Connection *the_one_and_only_connection;

    // A queue for any IscEvents that didn't belong to any Connection.
    static SLList<IscEvent *> external_events;

    // The connection to the server.
    IscSession   *server;

    // Initialized to 8, to skip past "LysKOM\n" at start of protocol.
    int 	  LysKOM_gotten;

    // When a message is received, it is first collected in the string
    // named unparsed.  The 'end of message' token is a newline that
    // doesn't appear inside a string.  It is hunted for using
    // hunt_nl_index. Strings are skipped with str_skip_left.
    prot_a_LyStr  unparsed;
    long 	  hunt_nl_index;
    long	  str_skip_left;
    // Gather the len of the next string here.
    long	  strlen_gather;

    Status receive_event(IscEvent *);
    void handle_package();

    // This information is fetched from the server on a need-to-know
    // basis by various questions, so that they can talk to old
    // servers by emulating the newer questions (often by getting
    // the same information by issuing older questions).
    Server_info   server_info;
    Bool          server_info_fetched;

    // Asynchronous messages are immediately sent to async_sink, if
    // that is initialized. Otherwise, they are discarded.
    void (*async_sink)(void *, prot_a_LyStr);
    void *sync_sink_data;

    // These are not, and should not currently be, implemented.
    Connection(const Connection&);
    Connection &operator =(const Connection&);
};

#endif

==> kom%2B%2B-0.4.tar.gz: kom++-0.4/libconnection/connection.h <==
// Handle a connection to a LysKOM server.
//
// $Id: connection.h,v 1.25 1995/11/24 21:47:35 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_CONNECTION_H
#define KOMXX_CONNECTION_H

/* Needed by isc.h */
#include <stddef.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <time.h>
/* End isc.h */

#include <SLList.h>
#include "server-info.h"

extern "C" {
#include "isc.h"
};

#include "prot-a-LyStr.h"
#include "misc.h"

// The class Connection handles communication with any number of
// LysKOM servers. It uses the ISC system. You can also have other
// IscSessions, and use static IscEvent*Connection::get_event(int
// timeout) to get events from them (nilkom uses this to read from the
// keyboard).
//
class Connection {
  public:
    // All Connections must share the same IscMaster. If you only have a
    // single Connection you can leave out the IscMaster argument, and an
    // IscMaster will be made for you. There is, however, no way for you
    // to get hold on that IscMaster.
    Connection(char *hostname, char *portnum, IscMaster *master=NULL);
    ~Connection();

    // Send a question. Don't flush it. All routines that await input
    // automatically flushes. Call drain() or get_event() to force the
    // questions to be flushed.
    void send_question(const prot_a_LyStr &str);

    // Parse any input that is available. Returns st_pending if no
    // input was available during TIMEOUT milliseconds. Returns
    // st_ok as soon as anything has been received. Note: there is
    // currently no way to wait for input on a specific Connection.
    // This will return as soon as there has been any event on any of
    // the IscSessions in the IscMaster. Returns st_error if something
    // is wrong with the connection - if that happens, you should
    // probably kill the connection and start a new one.
    static Status drain(int timeout=0);

    // Parse any input that is available. Return any IscEvent that has
    // been received from an IscSession that is not a Connection.
    // Return NULL if an event was received from a Connection (that
    // event has already been handled). Return an ISC_EVENT_TIMEOUT if
    // the timeout limit is reached. The event that is returned should
    // be disposed of with isc_dispose(). You are in trouble if this
    // returns an ISC_EVENT_ERROR. This might return the special value
    // &Connection::error_event if the connection was lost or something
    // similarily serious happens.
    static IscEvent *get_event(int timeout=0);
    static IscEvent error_event;

    // Register a function that will be called whenever an async
    // message has arrived. The first argument to register_async will
    // be passed as the first argument to the handler.
    void register_async(void *, void (*new_sinc)(void *, prot_a_LyStr));

    Server_info  * get_server_info();

  private:
    // The master control block. This is shared between all Connections.
    static IscMaster    *mcb;

    // FIXME+++: Support for multiple connections must be added.
    static Connection *the_one_and_only_connection;

    // A queue for any IscEvents that didn't belong to any Connection.
    static SLList<IscEvent *> external_events;

    // The connection to the server.
    IscSession   *server;

    // Initialized to 8, to skip past "LysKOM\n" at start of protocol.
    int 	  LysKOM_gotten;

    // When a message is received, it is first collected in the string
    // named unparsed.  The 'end of message' token is a newline that
    // doesn't appear inside a string.  It is hunted for using
    // hunt_nl_index. Strings are skipped with str_skip_left.
    prot_a_LyStr  unparsed;
    long 	  hunt_nl_index;
    long	  str_skip_left;
    // Gather the len of the next string here.
    long	  strlen_gather;

    Status receive_event(IscEvent *);
    void handle_package();

    // This information is fetched from the server on a need-to-know
    // basis by various questions, so that they can talk to old
    // servers by emulating the newer questions (often by getting
    // the same information by issuing older questions).
    Server_info   server_info;
    bool          server_info_fetched;

    // Asynchronous messages are immediately sent to async_sink, if
    // that is initialized. Otherwise, they are discarded.
    void (*async_sink)(void *, prot_a_LyStr);
    void *sync_sink_data;

    // These are not, and should not currently be, implemented.
    Connection(const Connection&);
    Connection &operator =(const Connection&);
};

#endif
